<?php
/**
 * Hashes a password and returns the hash based on the specified enc_type. 
 *
 * Original function from phpLDAPadmin project.
 *
 * @author The phpLDAPadmin development team
 * @package Phamm
 *
 * @param string $password_clear The password to hash in clear text.
 * @param string $enc_type Standard LDAP encryption type which must be one of
 *          crypt, md5, md5crypt, sha, smd5, ssha, or clear.
 * @return string The hashed password.
 */
function password_hash($password_clear)
{
	global $lang;
    $enc_type = strtolower( ENC_TYPE );
    switch( $enc_type )
    {
        case 'crypt':
            $new_value = '{CRYPT}' . crypt( $password_clear, random_salt(2) );
            break;
        case 'md5':
            $new_value = '{MD5}' . base64_encode( pack( 'H*' , md5( $password_clear) ) );
            break;
        case 'md5crypt':
            if( ! defined( 'CRYPT_MD5' ) || 0 == CRYPT_MD5 )
                print_message('error', $lang['install_not_support_md5crypt'] );
            $new_value = '{CRYPT}' . crypt( $password_clear , '$1$' . random_salt(9) );
            break;
        case 'blowfish':
            if( ! defined( 'CRYPT_BLOWFISH' ) || 0 == CRYPT_BLOWFISH )
                print_message('error', $lang['install_not_support_blowfish'] );
            $new_value = '{CRYPT}' . crypt( $password_clear , '$2$' . random_salt(13) );
            break;
        case 'sha':
            if( function_exists( 'mhash' ) ) {
                $new_value = '{SHA}' . base64_encode( mhash( MHASH_SHA1, $password_clear) );
            } else {
                print_message('error', $lang['install_no_mash'] );
            }
            break;
        case 'ssha':
            if( function_exists( 'mhash' ) && function_exists( 'mhash_keygen_s2k' ) ) {
                mt_srand( (double) microtime() * 1000000 );
                $salt = mhash_keygen_s2k( MHASH_SHA1, $password_clear, substr( pack( "h*", md5( mt_rand() ) ), 0, 8 ), 4 );
                $new_value = "{SSHA}".base64_encode( mhash( MHASH_SHA1, $password_clear.$salt ).$salt );
            } else {
                print_message('error', $lang['install_no_mash'] );
            }
            break;
        case 'smd5':
            if( function_exists( 'mhash' ) && function_exists( 'mhash_keygen_s2k' ) ) {
                mt_srand( (double) microtime() * 1000000 );
                $salt = mhash_keygen_s2k( MHASH_MD5, $password_clear, substr( pack( "h*", md5( mt_rand() ) ), 0, 8 ), 4 );
                $new_value = "{SMD5}".base64_encode( mhash( MHASH_MD5, $password_clear.$salt ).$salt );
            } else {
                print_message('error', $lang['install_no_mash'] );
            }
            break;
        case 'clear':
        default:
            $new_value = $password_clear;
	}
	return $new_value;
}
?>
